@@ -46,16 +46,11 @@ ConfigPtr QScreenBackend::config() const
     return s_internalConfig->toKScreenConfig();
 }
 
-QString QScreenBackend::setConfig(const ConfigPtr &config)
+std::expected<void, QString> QScreenBackend::setConfig(const ConfigPtr &config)
 {
-    if (!config) {
-        return QString();
-    }
-
-    qWarning() << "The QScreen backend for libkscreen is read-only,";
-    qWarning() << "setting a configuration is not supported.";
-    qWarning() << "You can force another backend using the KSCREEN_BACKEND env var.";
-    return QString();
+    return std::unexpected(
+        QStringLiteral("The QScreen backend for libkscreen is read-only, setting a configuration is not supported. You can force another backend using the "
+                       "KSCREEN_BACKEND env var"));
 }
 
 bool QScreenBackend::isValid() const
