@@ -178,21 +178,22 @@ void Doctor::setOptionList(const QStringList &outputArgs)
 
 OutputPtr Doctor::findOutput(const QString &query)
 {
-    // try as an output name or ID
-    for (const auto &output : m_config->outputs()) {
-        if (output->name() == query) {
-            return output;
-        }
+    const auto outputs = m_config->outputs();
+    const auto it = std::ranges::find_if(outputs, [&query](const auto &output) {
+        return query == output->name() || query == output->uuid();
+    });
+    if (it != outputs.end()) {
+        return *it;
     }
     bool ok;
     int id = query.toInt(&ok);
     if (!ok) {
-        cerr << "Output with name " << query << " not found." << Qt::endl;
+        cerr << "Output with name or uuid " << query << " not found." << Qt::endl;
         return OutputPtr();
     }
 
-    if (m_config->outputs().contains(id)) {
-        return m_config->outputs()[id];
+    if (const auto it = outputs.find(id); it != outputs.end()) {
+        return *it;
     } else {
         cerr << "Output with id " << id << " not found." << Qt::endl;
         return OutputPtr();
@@ -336,8 +337,10 @@ void Doctor::parseOutputArgs()
                         setHdrEnabled(output, true);
                     } else if (_enable == "disable") {
                         setHdrEnabled(output, false);
+                    } else if (_enable == "toggle") {
+                        setHdrEnabled(output, !output->isHdrEnabled());
                     } else {
-                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for hdr are \"enable\" and \"disable\"";
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for hdr are \"enable\", \"disable\" and \"toggle\"";
                         qApp->exit(9);
                         return;
                     }
@@ -355,8 +358,10 @@ void Doctor::parseOutputArgs()
                         setWcgEnabled(output, true);
                     } else if (_enable == "disable") {
                         setWcgEnabled(output, false);
+                    } else if (_enable == "toggle") {
+                        setWcgEnabled(output, !output->isWcgEnabled());
                     } else {
-                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for wcg are \"enable\" and \"disable\"";
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for wcg are \"enable\", \"disable\" and \"toggle\"";
                         qApp->exit(9);
                         return;
                     }
@@ -457,6 +462,56 @@ void Doctor::parseOutputArgs()
                     }
                     output->setDimming(dimming / 100.0);
                     m_changed = true;
+                } else if (ops.count() >= 4 && subcmd == "mirror") {
+                    if (ops[3] == "none") {
+                        output->setReplicationSource(0);
+                    } else {
+                        const auto source = findOutput(ops[3]);
+                        if (!source) {
+                            qCWarning(KSCREEN_DOCTOR, "No output %s", qPrintable(ops[3]));
+                            qApp->exit(9);
+                            return;
+                        }
+                        output->setReplicationSource(source->id());
+                    }
+                    m_changed = true;
+                } else if (ops.count() >= 4 && subcmd == "ddcCi") {
+                    const QString action = ops[3].toLower();
+                    if (action == "allow") {
+                        output->setDdcCiAllowed(true);
+                    } else if (action == "disallow") {
+                        output->setDdcCiAllowed(false);
+                    } else {
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for ddcCi are \"allow\" and \"disallow\"";
+                        qApp->exit(9);
+                        return;
+                    }
+                    m_changed = true;
+                } else if (ops.count() >= 4 && subcmd == "maxbpc") {
+                    if (ops[3] == "automatic") {
+                        output->setMaxBitsPerColor(0);
+                    } else {
+                        bool ok = false;
+                        const uint32_t bpc = ops[3].toUInt(&ok);
+                        if (!ok || bpc < 6 || bpc > 16 || bpc % 2 != 0) {
+                            qCWarning(KSCREEN_DOCTOR) << "Wrong input: Only 'automatic' and whole numbers between 6 and 16 are allowed";
+                            qApp->exit(9);
+                            return;
+                        }
+                        output->setMaxBitsPerColor(bpc);
+                    }
+                    m_changed = true;
+                } else if (ops.count() >= 4 && subcmd == "edrPolicy") {
+                    if (ops[3] == "never") {
+                        output->setEdrPolicy(Output::EdrPolicy::Never);
+                    } else if (ops[3] == "always") {
+                        output->setEdrPolicy(Output::EdrPolicy::Always);
+                    } else {
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Only 'never' and 'automatic' are valid";
+                        qApp->exit(9);
+                        return;
+                    }
+                    m_changed = true;
                 } else {
                     cerr << "Unable to parse arguments: " << op << Qt::endl;
                     qApp->exit(2);
@@ -487,8 +542,9 @@ void Doctor::configReceived(KScreen::ConfigOperation *op)
 
     parseOutputArgs();
 
-    if (const auto error = applyConfig()) {
-        cout << "applying config failed! " << *error << "\n";
+    const auto ret = applyConfig();
+    if (!ret.has_value()) {
+        cout << "applying config failed! " << ret.error() << "\n";
     }
     qApp->exit(0);
 }
@@ -517,12 +573,13 @@ void Doctor::showOutputs() const
 
     for (const auto &output : m_config->outputs()) {
         const auto endl = '\n';
-        cout << green << "Output: " << cr << output->id() << " " << output->name() << endl;
+        cout << green << "Output: " << cr << output->id() << " " << output->name() << " " << output->uuid() << endl;
         cout << "\t" << (output->isEnabled() ? green + QStringLiteral("enabled") : red + QStringLiteral("disabled")) << cr << endl;
         cout << "\t" << (output->isConnected() ? green + QStringLiteral("connected") : red + QStringLiteral("disconnected")) << cr << endl;
         cout << "\t" << (output->isEnabled() ? green : red) + QStringLiteral("priority ") << output->priority() << cr << endl;
         auto _type = typeString[output->type()];
         cout << "\t" << yellow << (_type.isEmpty() ? QStringLiteral("UnmappedOutputType") : _type) << cr << endl;
+        cout << "\t" << yellow << "replication source:" << cr << output->replicationSource() << endl;
         cout << "\t" << blue << "Modes: " << cr;
 
         const auto modes = output->modes();
@@ -634,7 +691,7 @@ void Doctor::showOutputs() const
             cout << cr << "incapable" << endl;
         }
         cout << yellow << "\tColor profile source: ";
-        if (output->capabilities() & Output::Capability::IccProfile) {
+        if (output->capabilities() & (Output::Capabilities(Output::Capability::IccProfile) | Output::Capability::BuiltInColorProfile)) {
             cout << cr;
             switch (output->colorProfileSource()) {
             case Output::ColorProfileSource::sRGB:
@@ -667,6 +724,46 @@ void Doctor::showOutputs() const
         } else {
             cout << cr << "unsupported" << endl;
         }
+        if (output->capabilities() & Output::Capability::DdcCi) {
+            cout << yellow << "\tDDC/CI: ";
+            cout << cr << (output->ddcCiAllowed() ? "allowed" : "disallowed") << endl;
+        }
+        cout << yellow << "\tColor resolution: ";
+        if (output->capabilities() & Output::Capability::MaxBitsPerColor) {
+            cout << cr;
+            if (output->maxBitsPerColor() != 0) {
+                cout << output->maxBitsPerColor() << " bits per color";
+            } else {
+                uint32_t autoBpc = 0;
+                if (output->colorPowerPreference() == Output::ColorPowerTradeoff::PreferEfficiency) {
+                    autoBpc = 10;
+                } else {
+                    autoBpc = 16;
+                }
+                if (output->automaticMaxBitsPerColorLimit()) {
+                    autoBpc = std::min(autoBpc, output->automaticMaxBitsPerColorLimit());
+                }
+                cout << "automatic (" << autoBpc << ")";
+            }
+            cout << ", range: [" << output->bitsPerColorRange().min << "; " << output->bitsPerColorRange().max << "] bits per color" << endl;
+        } else {
+            cout << "unknown" << endl;
+        }
+        cout << yellow << "\tAllow EDR: ";
+        if (output->capabilities() & Output::Capability::ExtendedDynamicRange) {
+            cout << cr;
+            switch (output->edrPolicy()) {
+            case Output::EdrPolicy::Never:
+                cout << "never";
+                break;
+            case Output::EdrPolicy::Always:
+                cout << "always";
+                break;
+            }
+            cout << endl;
+        } else {
+            cout << cr << "unsupported" << endl;
+        }
     }
 }
 
@@ -775,16 +872,16 @@ void Doctor::setWcgEnabled(OutputPtr output, bool enable)
     m_changed = true;
 }
 
-std::optional<QString> Doctor::applyConfig()
+std::expected<void, QString> Doctor::applyConfig()
 {
     if (!m_changed) {
-        return std::nullopt;
+        return {};
     }
     auto setop = new SetConfigOperation(m_config, this);
     if (setop->exec()) {
-        return std::nullopt;
+        return {};
     } else {
-        return setop->errorString();
+        return std::unexpected(setop->errorString());
     }
 }
 
