@@ -10,7 +10,7 @@
 #include <QGuiApplication>
 #include <QtGui/private/qtx11extras_p.h>
 
-#include "kscreendpms_debug.h"
+#include <kscreendpms_debug.h>
 
 #include <xcb/dpms.h>
 
